@@ -5,7 +5,7 @@ use Module::Install::Base;
 
 use vars qw{$VERSION $ISCORE @ISA};
 BEGIN {
-	$VERSION = '0.74';
+	$VERSION = '0.75';
 	$ISCORE  = 1;
 	@ISA     = qw{Module::Install::Base};
 }
@@ -20,11 +20,11 @@ sub install_share {
 
 	# If the module name and dist name don't math,
 	# the dist_dir won't subsequently work.
-	my $module_name = $self->name;
-	$module_name =~ s/-/::/g;
-	unless ( $module_name eq $self->module_name ) {
-		die "For File::ShareDir::dist_dir to work, the module and distribution names much match";
-	}
+	# my $module_name = $self->name;
+	# $module_name =~ s/-/::/g;
+	# if ( defined $self->module_name and $module_name ne $self->module_name ) {
+	#	die "For File::ShareDir::dist_dir to work, the module and distribution names much match";
+	# }
 
 	$self->postamble(<<"END_MAKEFILE");
 config ::
